# Code of Conduct

Everyone interacting in the btclib project's codebases, issue trackers,
chat rooms, and mailing lists is expected to follow the
[PSF Code of Conduct](https://www.python.org/psf/conduct/).
